10  '*********************************************************************
11  '                       TRANSFER.BAS
12  '
13  '            Tom Murray, Cascades Volcano Observatory
14  '                          1992
15  '---------------------------------------------------------------------
20  '  This program transfers data files from the seismic acquistion
21  '  computer to a host computer.  After insuring the files were copied
22  '  correctly, it erases them from the seismic acquisition computer,
23  '  freeing up memory for more files.  It then transfers the files from
24  '  the host to an archive medium (optical typically).  It also builds
25  '  an input file for the picking program so that the earthquakes can be
26  '  picked automatically or manually.
27  '
28  '  Files are moved by doing DIRs to obtain the file names and then XCOPYing
29  '  them.  XCOPY returns an error code that is used to prevent erasing
30  '  files that were not copied correctly.
31  '
32  '  WVA, WVC, LOG, and FFT files are transfered through this program.
33  '
34  '  To change target directories, edit the lines noted below to reflect
35  '  your system's configuration.
50  '------------------------------------------------------------------------
126 '     The following are the locations for the data on the acquisition
127 '     computer, the holding area on the computer running TRANSFER, and
128 '     the location of the archive media (typically an optical drive).
129 '     Associated with each location is a number indicating the amount
130 '     of free space available on the drive.  
131 '   
132 '     Individual users will want to edit the following lines to reflect
133 '     their own setups.
134 '
135 DATADIR$="J:\DATA"                  
136 TEMPDIR$="C:\QUAKES\TRANSFER\TEMP"         : TEMPSIZE#=0
137 ARCHVDIR$="O:\WV"                          : ARCHSIZE#=0
138 FFTDIR$="O:\FFT"                    
141 '      The location of the utility programs (IRIG and DEMUX)
142 UTILITY$="C:\QUAKES\UTILS"
145 '      The location of the log files
146 LOGDIR$="J:\XDETECT\V320"
147 '      Where the DMX files to be picked will end up
148 DMXDIR$="C:\QUAKES\SUDSPICK\DMX"
150 '      location of sudsplot
151 SUDSPLOT$="C:\QUAKES\UTILS"
299 '-----------------------------------------------------------------------
300 '      Now move the data from the acquisition computer to the temporary
301 '      holding area.  We don't move data directly to the archive device
302 '      because writing to the optical takes longer than writing to a hard
303 '      disk and we want to bother the acquisition guy as little as possible.
304 '
305 '      First use the DOS DIR command to get all the data files names in
306 '      a file that we can read through.  The files are sorted by time of
307 '      creation.
309 PRINT " BEGINNING PROCESS TO TRANSFER DATA FILES"
310 SHELL "DIR /B /O:N "+DATADIR$+"\*.*  > DATA.TRA"
311 SHELL "DIR /B /O:N "+LOGDIR$+"\*.LOG >DATA.LOG"
312 SHELL "COPY DATA.TRA+DATA.LOG DATA.TRA"
313 SHELL "DEL DATA.LOG"
314 '
315 '      Now read through the file and get the number of files for each type
316 LOGN%=0 : FFT%=0 : WV%=0 : TOT%=0
319 OPEN "DATA.TRA" FOR INPUT AS #1
320 IF EOF(1) THEN GOTO 350
322    LINE INPUT #1, ALINE$
325 '       see which ones we got
326    IF INSTR(ALINE$,".FFT") <> 0 THEN FFT%=FFT%+1 : TOT%=TOT%+1
327    IF INSTR(ALINE$,".LOG") <> 0 THEN LOGN%=LOGN%+1 : TOT%=TOT%+1
328    IF INSTR(ALINE$,".WV" ) <> 0 THEN WV%=WV%+1 : TOT%=TOT%+1
330    GOTO 320
350    CLOSE (1)
351 '      Because FFT files are done hourly and log files daily, we never 
352 '      transfer the last file since it is unlikely that it will be 
353 '      completed.
355 IF FFT% > 0 THEN FFT%=FFT%-1 : TOT%=TOT%-1
356 IF LOGN% > 0 THEN LOGN%=LOGN%-1 : TOT%=TOT%-1
370 CLS 
395 PRINT USING "#### WV, ### FFT, AND ## LOG FILES TO TRANSFER"; WV%,FFT%,LOGN%
396 PRINT " "
399 '-------------------------------------------------------------------------
400 '       if no files then we are done
405 IF TOT% < 1 THEN PRINT "NO FILES TO TRANSFER " : GOTO 9000
430 '      Now do a DIR for the temporary directory and see how much room
431 '      there is for the transfer.
432 PRINT "CHECKING AVAILABLE MEMORY IN TEMPORARY AND ARCHIVE DIRECTORIES"
435 SHELL "DIR "+TEMPDIR$+"\*.* >TEMP.TRA"
436 OPEN "TEMP.TRA" FOR INPUT AS #1
440    IF EOF(1) THEN GOTO 450
442    LINE INPUT #1, ALINE$
443    IF MID$(ALINE$,30,10)<>"bytes free" THEN GOTO 440
444 '    found bytes free
445 TEMPSIZE#=VAL(MID$(ALINE$,19,10))
450 CLOSE (1) : PRINT " "
461 PRINT USING "####.### MBYTES AVAILABLE IN TEMPORARY DIRECTORY"; ((TEMPSIZE#)/1000000#)
500 '       check to see how much room there is on the archive disk
535 SHELL "DIR "+ARCHVDIR$+"\*.* > ARCHVE.TRA"
536 OPEN "ARCHVE.TRA" FOR INPUT AS #1
537 '      if we get to the end with no "xxx bytes free" message then the
538 '      directory doen't exist and the optical probably needs mounting
540 IF EOF(1) THEN PRINT "ARCHIVE DISK (MSH SEISMIC) NOT MOUNTED - TRANSFER STOPPED" : SYSTEM
542    LINE INPUT #1, ALINE$
543    IF MID$(ALINE$,30,10)<>"bytes free" THEN GOTO 540
545    ARCHSIZE#=VAL(MID$(ALINE$,19,10))
546 '		found bytes free
550 CLOSE (1)
561 PRINT USING "####.### MBYTES AVAILABLE IN ARCHIVE DIRECTORY"; (ARCHSIZE#/1000000#)
562 PRINT " "
565 LINE INPUT "CONTINUE AND TRANSFER AS MUCH AS POSSIBLE (Y OR N)? "; IN$
570 IF IN$="N" THEN GOTO 9100
571 IF IN$="n" THEN GOTO 9100
599 '-------------------------------------------------------------------------
600 '       let's start moving files
601 '
602 '        we'll make a big batch file and then shell out to execute it.       
609 '
610 '       we'll use the xcopy command.  it returns an error code that we
611 '       can use to check if the copy was done correctly.  if so, the 
612 '       file is erased on the acquisition computer.  if not, the erase line
613 '       is skipped and we go to the label :WVFILE$.
616 '
617 PRINT "CREATING BATCH FILE MOVE_EM.BAT TO MOVE FILES OFF ACQUISITION COMPUTER"
618 OPEN "MOVE_EM.BAT" FOR OUTPUT AS #2
619 '       
620 ' 	keep track of how many fft and log files have been transfered
620 FFTD%=0 : LOGD%=0 
622 DUM1%=0   ' an incrementer used for the batch goto's
623 OPEN "DATA.TRA" FOR INPUT AS 1
625 IF EOF (1) THEN GOTO 695
630    LINE INPUT #1, ALINE$
631    DUM1%=DUM1%+1 : DUM1$=RIGHT$(STR$(DUM1%+1000),4)
632    IF INSTR(ALINE$,".FFT") = 0 THEN GOTO 650
633 '         see if this is the last one (it doesn't get transfered)
635       IF FFTD% = FFT% THEN GOTO 625
637       PRINT #2, "XCOPY "+DATADIR$+"\"+ALINE$+" "+TEMPDIR$+"\*.*"
639       PRINT #2, "IF ERRORLEVEL 1 GOTO F"+DUM1$
640       PRINT #2, "ERASE "+DATADIR$+"\"+ALINE$
641       PRINT #2, ":F"+DUM1$
642       FFTD%=FFTD%+1
649       GOTO 625
650    IF INSTR(ALINE$,".LOG") = 0 THEN GOTO 675
652 '         see if this is the last one (it doesn't get transfered)
654       IF LOGD% = LOGN% THEN GOTO 625
657       PRINT #2, "XCOPY "+LOGDIR$+"\"+ALINE$+" "+TEMPDIR$+"\*.*"
659       PRINT #2, "IF ERRORLEVEL 1 GOTO F"+DUM1$
660       PRINT #2, "ERASE "+LOGDIR$+"\"+ALINE$
661       PRINT #2, ":F"+DUM1$
664       LOGD%=LOGD%+1
674       GOTO 625
675    IF INSTR(ALINE$,".WV") = 0 THEN GOTO 685
678       PRINT #2, "XCOPY "+DATADIR$+"\"+ALINE$+" "+TEMPDIR$+"\*.*"
680       PRINT #2, "IF ERRORLEVEL 1 GOTO F"+DUM1$
682       PRINT #2, "ERASE "+DATADIR$+"\"+ALINE$
683       PRINT #2, ":F"+DUM1$
685       GOTO 625
690 '             batch file complete - execute it
695 CLOSE (1) : CLOSE (2) : SHELL "MOVE_EM.BAT"
698 CLS
700 ' PRINT "FILES MOVED OFF ACQUISITION COMPUTER"
1500 '------------------------------------------------------------------------
1501 '       before doing anything else, run the wv files through fixtime.exe
1502 '       this will use the IRIG code on channel 0 to correct the timing
1503 '       for the file.  also demux.exe to get them ready for sudspick
1504 '
1509 '       do it by creating a batch file
1510 SHELL "DIR  "+TEMPDIR$+"\*.WVC >WV_FILES.DAT"
1511 OPEN "WV_FILES.DAT" FOR INPUT AS #1
1515 OPEN "TIME_EM.BAT" FOR OUTPUT AS #2
1516 '       keep track of how many events
1517 WVS%=0
1520 IF EOF(1) THEN GOTO 1532
1521    LINE INPUT #1, ALINE$ 
1522    IF INSTR(ALINE$," WV")=0 THEN GOTO 1520
1523    WVS%=WVS%+1
1525    MID$(ALINE$,9,1)="." : ALINE$=LEFT$(ALINE$,12) : FWV$=ALINE$
1526    PRINT #2,UTILITY$+"\IRIG "+TEMPDIR$+"\"+ALINE$
1527    PRINT #2,UTILITY$+"\DEMUX "+TEMPDIR$+"\"+ALINE$+" "+DMXDIR$+"\"+MID$(ALINE$,1,8)+".DMX"
1528    GOTO 1520
1530 '       run it
1532 CLOSE (2): CLOSE (1)
1535 SHELL "TIME_EM.BAT"
1536 CLS
1549 '-------------------------------------------------------------------------
1600 '       before we forget, build the printer output to be used when picking
1601 '       the wv files. its name will be the same as the first wv file
1602 '
1603 '       lets make sure there are some wv files before progressing
1604 DUM1%=0
1605 IF WVS%=0 THEN GOTO 2000 ELSE PRFILE$=MID$(FWV$,1,8)+".PRT": DUM1%=0
1606 PRINT "CREATING "+PRFILE$+" TO USE AS WORKSHEET WHILE PICKING QUAKES"
1607 OPEN PRFILE$ FOR OUTPUT AS #2 : OPEN "WV_FILES.DAT" FOR INPUT AS #1
1608 PRINT #2, USING    "       WORKSHEET FOR PICKING EARTHQUAKES   \         \ \      \   PG ## OF ## ";DATE$,MID$(TIME$,1,5),1,(WVS%\20+1)
1609 PRINT #2,          "       +----------+-------+--+-----------------------------------------------+"
1610 IF EOF(1) THEN GOTO 1643
1611     LINE INPUT #1, ALINE$ : 
1620     IF INSTR(ALINE$," WV") = 0 THEN GOTO 1610 
1621     DUM1%=DUM1%+1 : WVFILE$=MID$(ALINE$,1,8) : WVTIME$=MID$(ALINE$,34,6)
1622     IF (DUM1% MOD 20) <>0 THEN GOTO 1626
1623     PRINT #2, CHR$(13)+CHR$(12);            'carriage return+formfeed
1624     PRINT #2,USING "                                           \         \ \       \  PG ## OF ## ";DATE$,MID$(TIME$,1,5),(DUM1%\20+1),(WVS%\20+1)
1625     PRINT #2,      "       +----------+-------+--+-----------------------------------------------+"
1626     IF (MID$(WVTIME$,1,2)="12") AND (RIGHT$(WVTIME$,1)="a") THEN MID$(WVTIME$,1,2)="00"
1627     IF (RIGHT$(WVTIME$,1)="p") AND (LEFT$(WVTIME$,2)<"12") THEN MID$(WVTIME$,1,2)=RIGHT$(STR$(VAL(LEFT$(WVTIME$,2))+112),2) 
1628     PRINT #2,USING "       | \      \ | \   \ |  |                                               |";WVFILE$, MID$(WVTIME$,1,5)
1629     PRINT #2,      "       |                                                                     |"
1630     PRINT #2,      "       +----------+-------+--+-----------------------------------------------+"
1640     GOTO 1610
1642 '        need a form-feed at the end
1643 PRINT #2, CHR$(13)+CHR$(12);
1644 CLOSE(2) : CLOSE (1)
1645 '       don't print it yet.  the printer noise will be used to alert the
1646 '       picker that the transfer was done.
2000 '----------------------------------------------------------------------
2001 '       now transfer the files from the temp directory to the archive
2002 '       disk.  fft files are put in daily directories under fftdir$.  all
2003 '       the wv, and log are put in monthly files under archvdir$
2010 '
2020 '       get our month array set up
2021 DIM MONTH$(12)
2022 DATA "JAN","FEB","MAR","APR","MAY","JUN","JUL","AUG","SEP","OCT","NOV","DEC"
2025 FOR I%=1 TO 12 : READ MONTH$(I%) : NEXT I%
2027 OLDDAY$=" " : OLDMON$=" "
2031 '       like before, build the batch file to do the transfer
2032 PRINT "CREATING ARCHIVE.BAT TO TRANFER FILES TO ARCHIVE DISK"
2033 SHELL "DIR /B "+TEMPDIR$+"\*.* >ERASEME.TRA"
2035 OPEN "ARCHIVE.BAT" FOR OUTPUT AS #2 : OPEN "ERASEME.TRA" FOR INPUT AS #1
2100 IF EOF(1) THEN GOTO 2200
2101     LINE INPUT #1, ALINE$
2102     IF INSTR(ALINE$,".WV")=0 THEN GOTO 2130
2103 '       get the year and month out of the name to use for the directory
2104        DUM1%=VAL(MID$(ALINE$,1,2))+100 : MONDIR$=RIGHT$(STR$(DUM1%),2)
2105        MONDIR$=MONTH$(VAL(MID$(ALINE$,3,2)))+MONDIR$
2106 '       if new, create the directory.  if its already there, no 
2107 '       harm is done
2108        IF OLDMON$<>MONDIR$ THEN OLDMON$=MONDIR$ : PRINT #2,"MKDIR "+ARCHVDIR$+"\"+MONDIR$ 
2110        PRINT #2,"XCOPY "+TEMPDIR$+"\"+ALINE$+" "+ARCHVDIR$+"\"+MONDIR$+"\*.*"
2111 '       because the processing uses dmx files we erase wv files after transfer 
2112        PRINT #2,"IF ERRORLEVEL 1 GOTO L"+DUM1$ 
2113        PRINT #2,"ERASE "+TEMPDIR$+"\"+ALINE$ : PRINT #2,":L"+DUM1$
2114        GOTO 2100
2130     IF INSTR(ALINE$,".LOG") = 0 THEN GOTO 2160
2131        DUM1$=RIGHT$(STR$(I%+1000),4)
2133 '       get the year and month out of the name to use for the directory
2134        DUM1%=VAL(MID$(ALINE$,1,2))+100 : MONDIR$=RIGHT$(STR$(DUM1%),2)
2135        MONDIR$=MONTH$(VAL(MID$(ALINE$,3,2)))+MONDIR$
2136 '       if new, create the directory.  if its already there, no 
2137 '       harm is done
2138        IF OLDMON$<>MONDIR$ THEN OLDMON$=MONDIR$ : PRINT #2,"MKDIR "+ARCHVDIR$+"\"+MONDIR$ 
2140        PRINT #2,"XCOPY "+TEMPDIR$+"\"+ALINE$+" "+ARCHVDIR$+"\"+MONDIR$+"\*.*"
2141        PRINT #2,"IF ERRORLEVEL 1 GOTO L"+DUM1$ 
2142        PRINT #2,"ERASE "+TEMPDIR$+"\"+ALINE$ : PRINT #2,":L"+DUM1$
2149        GOTO 2100
2160    IF INSTR(ALINE$,".INF") = 0 GOTO 2180
2161        DUM1$=RIGHT$(STR$(I%+1000),4)
2163 '       get the year and month out of the name to use for the directory
2164        DUM1%=VAL(MID$(ALINE$,1,2))+100 : MONDIR$=RIGHT$(STR$(DUM1%),2)
2165        MONDIR$=MONTH$(VAL(MID$(ALINE$,3,2)))+MONDIR$
2166 '       if new, create the directory.  if its already there, no 
2167 '       harm is done
2168        IF OLDMON$<>MONDIR$ THEN OLDMON$=MONDIR$ : PRINT #2,"MKDIR "+ARCHVDIR$+"\"+MONDIR$ 
2170        PRINT #2,"XCOPY "+TEMPDIR$+"\"+ALINE$+" "+ARCHVDIR$+"\"+MONDIR$+"\*.*"
2171        PRINT #2,"IF ERRORLEVEL 1 GOTO X"+DUM1$
2172        PRINT #2,"ERASE "+TEMPDIR$+"\"+ALINE$ : PRINT #2,":X"+DUM1$
2179        GOTO 2100
2180     IF INSTR(ALINE$,".FFT") = 0 THEN GOTO 2194
2181        DUM1$=RIGHT$(STR$(I%+1000),4)
2183 '       get the day,month, year for the subdirectory
2184        DUM1%=VAL(MID$(ALINE$,1,2))+100 : MONDIR$=RIGHT$(STR$(DUM1%),2)
2185        MONDIR$=MONTH$(VAL(MID$(ALINE$,3,2)))+MONDIR$
2186        DUM1%=VAL(MID$(ALINE$,5,2))+100 
2187        MONDIR$=RIGHT$(STR$(DUM1%),2)+MONDIR$
2188 '       if new, create the directory.  if its already there, no 
2189 '       harm is done
2190        IF OLDMON$<>MONDIR$ THEN OLDMON$=MONDIR$ : PRINT #2,"MKDIR "+FFTDIR$+"\"+MONDIR$ 
2191        PRINT #2,"XCOPY "+TEMPDIR$+"\"+ALINE$+" "+FFTDIR$+"\"+MONDIR$+"\*.*"
2192        PRINT #2,"IF ERRORLEVEL 1 GOTO F"+DUM1$ 
2193        PRINT #2,"ERASE "+TEMPDIR$+"\"+ALINE$ : PRINT #2,":F"+DUM1$
2194        GOTO 2100
2195 '       execute it
2200 CLOSE (2) : CLOSE (1) : SHELL "ARCHIVE.BAT"
2500 '------------------------------------------------------------------------
2587 '       getting close - now print our worksheet
2588 '       execute 2590 if a network printer is to be used, line 2591 if
2589 '       if a local printer is used
2590 SHELL "C:\LANTASTI\NET PRINT "+PRFILE$+" LPT1" 
2591 'SHELL "PRINT "+PRFILE$
2600 '       and now use sudsplot to print out the waveforms
2602 '
2604 OPEN "WV_FILES.DAT" FOR INPUT AS #1
2607 OPEN "WAVEPRT.BAT" FOR OUTPUT AS #2 
2610 IF EOF(1) THEN GOTO 2633
2611     LINE INPUT #1, ALINE$
2612     IF INSTR(ALINE$," WV") = 0 THEN GOTO 2610
2613     MID$(ALINE$,9,1)="." : ALINE$=LEFT$(ALINE$,12)
2614 '      sudsplot requires us to be in the sudsplot directory
2615     PRINT #2, MID$(SUDSPLOT$,1,2) : PRINT #2, "CD "+SUDSPLOT$
2616     PRINT #2,SUDSPLOT$+"\SUDSPLOT /P1 /T16 /J12 /L20 /X "+DMXDIR$+"\"+LEFT$(ALINE$,8)+".DMX"  
2630     GOTO 2610
2633 CLOSE(2) : CLOSE (1)
2639 ' SUDSPLOT cannot be run by GWBASIC SHELL. Run it from TRANSFER.BAT instead
2640 SHELL "WAVEPRT.BAT" 
2641 BEEP:BEEP:BEEP:BEEP : CLS : SYSTEM
8999'------------------------------------------------------------
9000 PRINT "NO FILES TO TRANSFER - BYE" : :BEEP:BEEP:BEEP:BEEP: SYSTEM
9100 PRINT "CLEAR OUT SOME MEMORY AND TRY AGAIN - BYE" : SYSTEM
